<?php

namespace Teknisa\EST\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;


class AlmoxarifadoCountLocalEstoque extends \Teknisa\EST\Controllers\TeknisaCrud {
	protected $dataSourceName = 'almoxarifado_countLocalEstoque';
	protected $parameterBagColumns = array('CDFILIAL');
	protected $Ger03700Service;
	protected $connection;
	protected $crudService;
	protected $entityManager;

	public function __construct($crudService, $parameterBag, $Ger03700Service, $entityManager) {
		parent::__construct($crudService, $parameterBag);
		$this->crudService = $crudService;
		$this->Ger03700Service = $Ger03700Service;
		$this->connection = $entityManager->getConnection();
		$this->entityManager = $entityManager;
	}

	public function save(DTO\Request $request, DTO\Response $response){
		$dataSet = $request->getDataSet();
		$rows = $dataSet->getRows();
		$row = $rows[0];

		$this->connection->beginTransaction();
		try{
			$rowsToSave = $this->crudService->getRowsToSave($request, $this->dataSourceName);
			$this->crudService->save($this->dataSourceName, $rowsToSave);
			$this->Ger03700Service->updateLocalEstoque($row);
			$this->connection->commit();
		} catch (\Exception $e){
			$response->setError(new Error($e->getMessage(), 500));
			$this->connection->rollBack();
		}
	}

	public function delete(DTO\Request $request, DTO\Response $response){
		$row = $request->getRow();
		$this->connection->beginTransaction();
		try {
			
			$this->deleteAllLocalizacoes($request, $response);
			$this->Ger03700Service->deleteAlmoxarifado($row['CDFILIAL'], $row['CDALMOXARIFE'], $row['NRORG']);
			$this->entityManager->flush();
			$this->connection->commit();
		} catch	(\Exception $e){
			if(strpos($e->getMessage(), 'ORA-02292') === false){
				$str = $e->getMessage();
			} else {
				$str = "Exclusão bloqueada! Existem restrições na base de dados que impedem a exclusão da almoxarifado.";
			}
			$response->setError(new Error($str, 500));
			$this->connection->rollBack();
		}
	}
	
		private function deleteAllLocalizacoes(DTO\Request $request, DTO\Response $response){
		$row = $request->getRow();
		$this->connection->beginTransaction();
		try {
			
			$this->Ger03700Service->checaAlmoxarifadoPadrao($row['CDFILIAL'], $row['CDALMOXARIFE']);
			$this->Ger03700Service->deleteAllLocalizacoes($row['CDFILIAL'], $row['CDALMOXARIFE']);
			$this->entityManager->flush();
			
			$this->connection->commit();
		} catch	(\Exception $e){
			if(strpos($e->getMessage(), 'ORA-02292') === false){
				$str = $e->getMessage();
			} else {
				$str = "Exclusão bloqueada! Existem restrições na base de dados que impedem a exclusão das localizações.";
			}
			$response->setError(new Error($str, 500));
			$this->connection->rollBack();
		}
	}
}
